@@ -45,6 +45,7 @@ InvalidFormat: ...
 
 from stdnum.exceptions import *
 from stdnum.nl.bsn import checksum, compact
+from stdnum.util import isdigits
 
 
 __all__ = ['compact', 'validate', 'is_valid']
@@ -55,7 +56,7 @@ def validate(number):
     and whether the check digit is correct and whether it starts with the
     right sequence."""
     number = compact(number)
-    if not number.isdigit() or int(number) <= 0:
+    if not isdigits(number) or int(number) <= 0:
         raise InvalidFormat()
     if not number.startswith('10'):
         raise InvalidFormat()
